/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_iem_cdd_update_case.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    FCF to ECM update of CDD Cases
+------------------------------------------------------------------------------+
| USAGE:   %fcf_iem_cdd_update_case(ds=)
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2013-2014 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro fcf_iem_cdd_update_case(ds=);

    /*------------------------------------------
     * Set error code to 0 and message to blank
     *------------------------------------------*/

    %let trans_rc = 0;
    %let _fcfmsg_=;

	/*==========================================================================* 
	 * Step:            Join                                                    *
	 * Transform:       Join                                                    * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Tables:   Input DS - &ds						                    *
	 *                  CASE_LIVE - ecm_db.CASE_LIVE                            *
	 * Target Table:    Join - work.stg_case_upd                                *
	 *==========================================================================*/ 

	data _null_;
		call symput('current_dt',put(datetime(),datetime22.));
	run;

	proc datasets lib = work nolist nowarn memtype = (data view);
	   delete stg_case_upd;
	quit;

	proc sql;
	   create table work.stg_case_upd as
	   select
	      CASE_LIVE.CASE_RK,
	      ("&current_dt"dt) as VALID_FROM_DTTM,
	      CASE_LIVE.VALID_TO_DTTM,
	      cdd_upd_cases.CASE_ID,
	      cdd_upd_cases.SOURCE_SYSTEM_CD,
	      CASE_LIVE.CASE_TYPE_CD,
	      CASE_LIVE.CASE_CATEGORY_CD,
	      CASE_LIVE.CASE_SUBCATEGORY_CD,
	      CASE_LIVE.CASE_STATUS_CD,
	      CASE_LIVE.CASE_DISPOSITION_CD,
	      CASE_LIVE.CASE_DESC,
	      CASE_LIVE.CASE_LINK_SK,
	      CASE_LIVE.PRIORITY_CD,
	      CASE_LIVE.REGULATORY_RPT_RQD_FLG,
	      CASE_LIVE.INVESTIGATOR_USER_ID,
	      CASE_LIVE.OPEN_DTTM,
	      CASE_LIVE.REOPEN_DTTM,
	      CASE_LIVE.CLOSE_DTTM,
	      CASE_LIVE.UI_DEF_FILE_NM,
	      CASE_LIVE.CREATE_USER_ID,
	      CASE_LIVE.CREATE_DTTM,
	      CASE_LIVE.UPDATE_USER_ID,
	      CASE_LIVE.VERSION_NO+1 as VERSION_NO,
	      CASE_LIVE.DELETE_FLG,
	      cdd_upd_cases.NEXT_REVIEW_DATE,
	      cdd_upd_cases.LAST_REVIEW_DATE,
	      CASE_LIVE.VALID_FROM_DTTM as OLD_VALID_FROM_DTTM
	   from
	      &ds as cdd_upd_cases, 
	      ecm_db.CASE_LIVE
	   where
	      cdd_upd_cases.CASE_RK = CASE_LIVE.CASE_RK
	   ;
	quit;

	%global etls_sql_pushDown;
	%let etls_sql_pushDown = &sys_sql_ip_all;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 



	/**  Step end Join **/

	/*==========================================================================* 
	 * Step:            Update                                                  *
	 * Transform:       Update                                                  * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Join - work.stg_case_upd                                *
	 * Target Table:    CASE_LIVE - ecm_db.CASE_LIVE                            *
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.stg_case_upd); 

	proc sql;
	   update ecm_db.CASE_LIVE
	      set 
	         VALID_FROM_DTTM= (
	            select
	               stg_case_upd.VALID_FROM_DTTM
	            from
	               work.stg_case_upd as stg_case_upd
	            where
	               CASE_LIVE.CASE_RK = stg_case_upd.CASE_RK
	         ),
	         VERSION_NO= VERSION_NO + 1
	      where
	         CASE_RK IN (
	            select
	               stg_case_upd.CASE_RK
	            from
	               work.stg_case_upd as stg_case_upd
	         )
	   ;
	quit;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Update                                                  *
	 * Transform:       Update                                                  * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Join - work.stg_case_upd                                *
	 * Target Table:    CASE_VERSION - ecm_db.CASE_VERSION                      *
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.stg_case_upd); 

	proc sql;
	   update ecm_db.CASE_VERSION
	      set 
	         VALID_TO_DTTM= (
	            select
	               stg_case_upd.VALID_FROM_DTTM as VALID_TO_DTTM
	            from
	               work.stg_case_upd as stg_case_upd
	            where
	               CASE_VERSION.CASE_RK = stg_case_upd.CASE_RK
	         )
	      where
	         VALID_TO_DTTM = .
	         and CASE_RK IN (
	            select
	               stg_case_upd.CASE_RK
	            from
	               work.stg_case_upd as stg_case_upd
	         )
	   ;
	quit;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Table Loader                                            *
	 * Transform:       Table Loader (Version 2.1)                              * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Join - work.stg_case_upd                                *
	 * Target Table:    CASE_VERSION - ecm_db.CASE_VERSION                      *
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.stg_case_upd); 

	proc append base = ecm_db.CASE_VERSION 
		data = &SOURCEDS force ; 
	run; 
	  
	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 
	   
	/*==========================================================================* 
	 * Step:            Table Loader                                            *
	 * Transform:       Table Loader (Version 2.1)                              * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Join - work.stg_case_upd                                *
	 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT                            *
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.stg_case_upd); 
	
	data _null_;
		call symput('current_dt',put(datetime(),datetime22.));
	run;

	proc datasets lib = iem nolist nowarn memtype = (data view);
        delete new_events;
    quit;

	data iem.new_events;
		if 0 then set ecm_db.ecm_event;
		set &SOURCEDS. (keep= CASE_RK VERSION_NO);
		BUSINESS_OBJECT_NM = "CASE";
		BUSINESS_OBJECT_RK = CASE_RK;
		EVENT_TYPE_CD = "SAVENT";
		EVENT_DESC = trim("event.save.version.fmt.txt"||"	"||trim(left(put(VERSION_NO,8.))));
		CREATE_USER_ID = "&ecm_user";
		CREATE_DTTM = ("&current_dt"dt);
		drop CASE_RK VERSION_NO;
	run;
	      
	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	%fcf_get_ecm_sequence_ids(in=iem.new_events,out=iem.new_events,type=event,block=&iem_performance_load);
	
	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

    /*==========================================================================* 
     * Step:            Table Loader                                            * 
     * Transform:       Table Loader (Version 2.1)                              * 
     * Description:                                                             * 
     *                                                                          * 
     * Source Table:    New Events - iem.new_events                             * 
     * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT                            * 
     *==========================================================================*/

    %let SOURCEDS = %nrquote(iem.new_events);

	proc append base = ecm_db.ECM_EVENT
        data = &SOURCEDS force; 
    run;

    %fcf_rcset(&syserr);

    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: FCF: IEM: Unable to append to ECM_EVENT;

        %fcf_put_error;
        %goto MACRO_END;
    %end;

	/*==========================================================================* 
	 * Step:            Extract                                                 *
	 * Transform:       Extract                                                 * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Join - work.stg_case_upd                                *
	 * Target Table:    Extracted Date UDFs -                                   *
	 *                   work.extracted_date_udfs                               * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.stg_case_upd); 

	proc datasets lib = work nolist nowarn memtype = (data view);
	   delete extracted_date_udfs;
	quit;

	proc sql;
	   create table work.extracted_date_udfs as
	      select
	         CASE_RK as ECM_RK,
	         VALID_FROM_DTTM,
	         NEXT_REVIEW_DATE,
	         LAST_REVIEW_DATE
	   from &SOURCEDS
	   ;
	quit;

	%let SOURCEDS = work.extracted_date_udfs;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Sort                                                    *
	 * Transform:       Sort                                                    * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Extracted Date UDFs -                                   *
	 *                   work.extracted_date_udfs                               * 
	 * Target Table:    Sorted extracted Date UDFs -                            *
	 *                   work.sorted_extracted_date_udfs                        * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.extracted_date_udfs); 

	proc datasets lib = work nolist nowarn memtype = (data view);
	   delete sorted_extracted_date_udfs;
	quit;

	proc sort data = &SOURCEDS 
	   out = work.sorted_extracted_date_udfs; 
	   by
          ECM_RK
          VALID_FROM_DTTM
	   ;
	run; 

	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Transpose                                               *
	 * Transform:       Transpose                                               * 
	 *                                                                          * 
	 * Source Table:    Sorted extracted Date UDFs -                            *
	 *                   work.sorted_extracted_date_udfs                        * 
	 * Target Table:    Transpose Date UDFs -                                   *
	 *                   work.transposed_date_udfs                              * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.sorted_extracted_date_udfs); 

	%let _INPUT = work.sorted_extracted_date_udfs;
	%let _OUTPUT = work.transposed_date_udfs;
	%let _OUTPUT_options = %nrquote(where = (n(ecm_rk)>0));
	
	proc datasets lib=work nolist nowarn memtype = (data view);
	   delete transposed_date_udfs;
	quit;

	%let varColumns = NEXT_REVIEW_DATE LAST_REVIEW_DATE;
	%let byColumns = ECM_RK VALID_FROM_DTTM;
	
	proc transpose data = &_INPUT out = &_OUTPUT (&_OUTPUT_options);
		by &byColumns;
		var &varColumns;
	run;

	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end;

	/*==========================================================================* 
	 * Step:            Data Validation                                         *
	 * Transform:       Data Validation                                         * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Transpose Date UDFs -                                   *
	 *                   work.transposed_date_udfs                              * 
	 * Target Table:    Staged Date UDFs -                                      *
	 *                   work.validated_date_udfs                               * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.transposed_date_udfs); 

    proc datasets lib = work nolist nowarn memtype = (data view);
        delete validated_numeric_udfs;
    quit;

    proc datasets lib = work nolist nowarn memtype = (data view);
        delete temp_errors;
    quit;
 

	data work.validated_date_udfs
	     (keep = ECM_RK VALID_FROM_DTTM _NAME_ COL1)
	    work.temp_errors
	     (keep = ECM_RK VALID_FROM_DTTM _NAME_ COL1);

		set &SOURCEDS end=eof;

		i_move = 0;

		if (_NAME_ = 'NEXT_REVIEW_DATE'  & COL1 =.) then 
			do; 
				i_move = 1; 
			end; 
		else 
			do; 
			end; 

		if (_NAME_ = 'LAST_REVIEW_DATE'  & COL1 =.) then 
			do; 
				i_move = 1; 
			end; 
		else 
			do; 
			end; 


		if (i_move) then 
			output work.temp_errors;

		else 
			output work.validated_date_udfs;
		 
		if eof then 
			do; 
			end; 
	run; 

	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Table Loader                                            *
	 * Transform:       Table Loader (Version 2.1)                              * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    Validated Character UDFs -                              *
	 *                   work.validated_date_udfs                 		        * 
	 * Target Table:    New Character UDFs -                                    *
	 *                   work.new_date_udfs                                		* 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.validated_date_udfs); 

    proc datasets lib = work nolist nowarn memtype = (data view);
        delete new_date_udfs;
    quit;

	data new_date_udfs;
		if 0 then set ecm_db.case_udf_date_value;
		set &SOURCEDS. (keep= ECM_RK _NAME_ COL1 VALID_FROM_DTTM);
		CASE_RK = ECM_RK;
		VALID_FROM_DTTM = VALID_FROM_DTTM;
		UDF_TABLE_NM = "CASE";
		UDF_NM = _NAME_;
		ROW_NO = 1;
		UDF_VALUE = COL1;
		drop ECM_RK _NAME_ COL1;
	run;

	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

    %let SOURCEDS = work.new_date_udfs;
	   

	/*==========================================================================* 
	 * Step:            Join                                                    *
	 * Transform:       Join                                                    * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Tables:   CASE_UDF_DATE_VALUE -                                   *
	 *                   ecm_db.CASE_UDF_DATE_VALUE                             * 
	 *                  Join - work.stg_case_upd                                *
	 * Target Table:    Existing Date UDFs -                                    *
	 *                   work.existing_date_udfs                                * 
	 *==========================================================================*/ 

	proc datasets lib = work nolist nowarn memtype = (data view);
	   delete existing_date_udfs;
	quit;

	proc sql;
	   create table work.existing_date_udfs as
	   select
	      CASE_UDF_DATE_VALUE.CASE_RK,
	      stg_case_upd.VALID_FROM_DTTM,
	      CASE_UDF_DATE_VALUE.UDF_TABLE_NM,
	      CASE_UDF_DATE_VALUE.UDF_NM,
	      CASE_UDF_DATE_VALUE.ROW_NO,
	      CASE_UDF_DATE_VALUE.UDF_VALUE
	   from
	      work.stg_case_upd, 
	      ecm_db.CASE_UDF_DATE_VALUE
	   where
	      stg_case_upd.CASE_RK = CASE_UDF_DATE_VALUE.CASE_RK
	      and stg_case_upd.OLD_VALID_FROM_DTTM = CASE_UDF_DATE_VALUE.VALID_FROM_DTTM
	      and CASE_UDF_DATE_VALUE.UDF_NM NOT IN ('NEXT_REVIEW_DATE','LAST_REVIEW_DATE')
	   ;
	quit;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Append                                                  *
	 * Transform:       Append                                                  * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Tables:   Staged Date UDFs -                                      *
	 *                   work.new_date_udfs                                     * 
	 *                  Existing Date UDFs -                                    *
	 *                   work.existing_date_udfs                                * 
	 * Target Table:    All Date UDFs - work.all_date_udfs                      *
	 *==========================================================================*/ 

	proc datasets lib = work nolist nowarn memtype = (data view);
		delete all_date_udfs;
	quit;

	data work.all_date_udfs / view=work.all_date_udfs;
		set work.new_date_udfs
		    work.existing_date_udfs;
		keep CASE_RK VALID_FROM_DTTM UDF_TABLE_NM UDF_NM ROW_NO UDF_VALUE; 
	run;

	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Table Loader                                            *
	 * Transform:       Table Loader (Version 2.1)                              * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    All Date UDFs - work.all_date_udfs                      *
	 * Target Table:    CASE_UDF_DATE_VALUE -                                   *
	 *                   ecm_db.CASE_UDF_DATE_VALUE                             * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.all_date_udfs); 

	proc append base = ecm_db.CASE_UDF_DATE_VALUE 
		data = &SOURCEDS force ; 
	run; 

	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 
	   
	/*==========================================================================* 
	 * Step:            Join                                                    *
	 * Transform:       Join                                                    * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Tables:   CASE_UDF_CHAR_VALUE -                                   *
	 *                   ecm_db.CASE_UDF_CHAR_VALUE                             * 
	 *                  Join - work.stg_case_upd                                *
	 * Target Table:    All char UDFs without updated values                    *
	 *                   - work.all_char_udfs_wo_upd                            * 
	 *==========================================================================*/ 

	proc datasets lib = work nolist nowarn memtype = (data view);
	   delete all_char_udfs_wo_upd;
	quit;

	proc sql;
	   create table work.all_char_udfs_wo_upd as
	   select
	      CASE_UDF_CHAR_VALUE.CASE_RK as CASE_RK,
	      stg_case_upd.VALID_FROM_DTTM,
	      CASE_UDF_CHAR_VALUE.UDF_TABLE_NM,
	      CASE_UDF_CHAR_VALUE.UDF_NM,
	      CASE_UDF_CHAR_VALUE.ROW_NO,
	      CASE_UDF_CHAR_VALUE.UDF_VALUE
	   from
	      work.stg_case_upd, 
	      ecm_db.CASE_UDF_CHAR_VALUE
	   where
	      stg_case_upd.CASE_RK = CASE_UDF_CHAR_VALUE.CASE_RK
	      and stg_case_upd.OLD_VALID_FROM_DTTM = CASE_UDF_CHAR_VALUE.VALID_FROM_DTTM
	   ;
	quit;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Table Loader                                            *
	 * Transform:       Table Loader (Version 2.1)                              * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    All char UDFs without updated values                    *
	 *                   - work.all_char_udfs_wo_upd                            * 
	 * Target Table:    CASE_UDF_CHAR_VALUE -                                   *
	 *                   ecm_db.CASE_UDF_CHAR_VALUE                             * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.all_char_udfs_wo_upd); 

	proc append base = ecm_db.CASE_UDF_CHAR_VALUE 
		data = &SOURCEDS force ; 
	run; 
	   
	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 
	   
	/*==========================================================================* 
	 * Step:            Join                                                    *
	 * Transform:       Join                                                    * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Tables:   CASE_UDF_NUM_VALUE -                                    *
	 *                   ecm_db.CASE_UDF_NUM_VALUE                              * 
	 *                  Join - work.stg_case_upd                                *
	 * Target Table:    All num UDFs without updated values -                   *
	 *                   work.all_num_udf_wo_char_upd                           * 
	 *==========================================================================*/ 

	proc datasets lib = work nolist nowarn memtype = (data view);
	   delete all_num_udf_wo_char_upd;
	quit;

	proc sql;
	   create table work.all_num_udf_wo_char_upd as
	   select
	      CASE_UDF_NUM_VALUE.CASE_RK,
	      stg_case_upd.VALID_FROM_DTTM as VALID_FROM_DTTM,
	      CASE_UDF_NUM_VALUE.UDF_TABLE_NM,
	      CASE_UDF_NUM_VALUE.UDF_NM,
	      CASE_UDF_NUM_VALUE.ROW_NO,
	      CASE_UDF_NUM_VALUE.UDF_VALUE
	   from
	      work.stg_case_upd, 
	      ecm_db.CASE_UDF_NUM_VALUE
	   where
	      stg_case_upd.CASE_RK = CASE_UDF_NUM_VALUE.CASE_RK
	      and stg_case_upd.OLD_VALID_FROM_DTTM = CASE_UDF_NUM_VALUE.VALID_FROM_DTTM
	   ;
	quit;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Table Loader                                            *
	 * Transform:       Table Loader (Version 2.1)                              * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    All num UDFs without updated values -                   *
	 *                   work.all_num_udf_wo_char_upd                           * 
	 * Target Table:    CASE_UDF_NUM_VALUE -                                    *
	 *                   ecm_db.CASE_UDF_NUM_VALUE                              * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.all_num_udf_wo_char_upd); 
	   
	proc append base = ecm_db.CASE_UDF_NUM_VALUE 
		data = &SOURCEDS force ; 
	run; 
	   
	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 
	 
	/*==========================================================================* 
	 * Step:            Join                                                    *
	 * Transform:       Join                                                    * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Tables:   CASE_UDF_LGCHR_VALUE -                                  *
	 *                   ecm_db.CASE_UDF_LGCHR_VALUE                            * 
	 *                  Join - work.stg_case_upd                                *
	 * Target Table:    All lgchar UDFs -                                       *
	 *                   work.all_lgchar_udfs                                   * 
	 *==========================================================================*/ 

	proc datasets lib = work nolist nowarn memtype = (data view);
	   delete all_lgchar_udfs;
	quit;

	proc sql;
	   create table work.all_lgchar_udfs as
	   select
	      CASE_UDF_LGCHR_VALUE.CASE_RK as CASE_RK,
	      stg_case_upd.VALID_FROM_DTTM as VALID_FROM_DTTM,
	      CASE_UDF_LGCHR_VALUE.UDF_TABLE_NM,
	      CASE_UDF_LGCHR_VALUE.UDF_NM,
	      CASE_UDF_LGCHR_VALUE.ROW_NO,
	      CASE_UDF_LGCHR_VALUE.UDF_VALUE
	   from
	      work.stg_case_upd, 
	      ecm_db.CASE_UDF_LGCHR_VALUE
	   where
	      stg_case_upd.OLD_VALID_FROM_DTTM = CASE_UDF_LGCHR_VALUE.VALID_FROM_DTTM
	      and stg_case_upd.CASE_RK = CASE_UDF_LGCHR_VALUE.CASE_RK
	   ;
	quit;

	%fcf_rcset(&sqlrc);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 

	/*==========================================================================* 
	 * Step:            Table Loader                                            *
	 * Transform:       Table Loader (Version 2.1)                              * 
	 * Description:                                                             * 
	 *                                                                          * 
	 * Source Table:    All lgchar UDFs -                                       *
	 *                   work.all_lgchar_udfs                                   * 
	 * Target Table:    CASE_UDF_LGCHR_VALUE -                                  *
	 *                   ecm_db.CASE_UDF_LGCHR_VALUE                            * 
	 *==========================================================================*/ 

	%let SOURCEDS = %nrquote(work.all_lgchar_udfs); 
	   
	proc append base = ecm_db.CASE_UDF_LGCHR_VALUE 
		data = &SOURCEDS force ; 
	run; 

	%fcf_rcset(&syserr);

	%if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
		%let _fcfmsg_=ERROR: FCF: IEM: Error encountered executing FCF_IEM_CDD_UPDATE_CASE;
		%fcf_put_error;
		%goto MACRO_END;
	%end; 
	   
%MACRO_END:

    %if &trans_rc eq 3 or &trans_rc ge 5 %then
        %fcf_execute_macro(fcf_error);
    %else %do;
        %fcf_execute_macro(fcf_success);
    %end;

%mend;

